==> ah-form-builder-sample-0.6.14.tgz: package/es/index.js <==
var _jsxFileName = "/var/apps/ah-form-builder/src/index.js";

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; subClass.__proto__ = superClass; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import App from './components/app/App';
import { Provider } from 'react-redux';
import { createMuiTheme } from '@material-ui/core/styles';
import { ThemeProvider } from '@material-ui/styles';
import { blue } from '@material-ui/core/colors';
import './styles/index.scss';
import 'bootstrap/dist/css/bootstrap.css';
import { applyMiddleware, createStore } from 'redux';
import rootReducer from './reducers/rootReducer';
import thunk from 'redux-thunk';
var theme = createMuiTheme({
  palette: {
    primary: {
      main: blue[700]
    }
  }
});

var FormBuilder = /*#__PURE__*/function (_React$Component) {
  _inheritsLoose(FormBuilder, _React$Component);

  function FormBuilder() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _React$Component.call.apply(_React$Component, [this].concat(args)) || this;

    _defineProperty(_assertThisInitialized(_this), "state", {
      loading: false
    });

    return _this;
  }

  var _proto = FormBuilder.prototype;

  _proto.componentDidMount = function componentDidMount() {// setTimeout(() => {
    //   this.setState({
    //     loading: false
    //   })
    // }, 1000)
  };

  _proto.render = function render() {
    if (this.state.loading) {
      return /*#__PURE__*/React.createElement("div", {
        __self: this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 37,
          columnNumber: 9
        }
      }, "Loading...");
    }

    return /*#__PURE__*/React.createElement(Provider, {
      store: createStore(rootReducer, applyMiddleware(thunk)),
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 43,
        columnNumber: 7
      }
    }, /*#__PURE__*/React.createElement(ThemeProvider, {
      theme: this.props.theme ? this.props.theme : theme,
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 47,
        columnNumber: 9
      }
    }, /*#__PURE__*/React.createElement("div", {
      className: "container-el",
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 48,
        columnNumber: 11
      }
    }, /*#__PURE__*/React.createElement(App, {
      onSubmit: this.props.onSubmit,
      formData: this.props.data,
      predefinedEndpoint: this.props.predefinedEndpoint,
      fileUploadUrl: this.props.fileUploadUrl,
      conditionableFields: this.props.conditionableFields,
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 49,
        columnNumber: 13
      }
    }))));
  };

  return FormBuilder;
}(React.Component);

export default FormBuilder;

==> ah-form-builder-sample-0.6.16.tgz: package/es/index.js <==
var _jsxFileName = "/var/apps/ah-form-builder/src/index.js";

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; subClass.__proto__ = superClass; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import App from './components/app/App';
import { Provider } from 'react-redux';
import { createMuiTheme } from '@material-ui/core/styles';
import { ThemeProvider } from '@material-ui/styles';
import { blue } from '@material-ui/core/colors';
import './styles/index.scss';
import 'bootstrap/dist/css/bootstrap.css';
import { applyMiddleware, createStore } from 'redux';
import rootReducer from './reducers/rootReducer';
import thunk from 'redux-thunk';
var theme = createMuiTheme({
  palette: {
    primary: {
      main: blue[700]
    }
  }
});

var FormBuilder = /*#__PURE__*/function (_React$Component) {
  _inheritsLoose(FormBuilder, _React$Component);

  function FormBuilder() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _React$Component.call.apply(_React$Component, [this].concat(args)) || this;

    _defineProperty(_assertThisInitialized(_this), "state", {
      loading: true
    });

    return _this;
  }

  var _proto = FormBuilder.prototype;

  _proto.componentDidMount = function componentDidMount() {
    var _this2 = this;

    setTimeout(function () {
      _this2.setState({
        loading: false
      });
    }, 500);
  };

  _proto.shouldComponentUpdate = function shouldComponentUpdate(nextProps, nextState, nextContext) {
    return this.state.loading;
  };

  _proto.render = function render() {
    if (this.state.loading) {
      return /*#__PURE__*/React.createElement("div", {
        __self: this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 41,
          columnNumber: 9
        }
      }, "Loading...");
    }

    return /*#__PURE__*/React.createElement(Provider, {
      store: createStore(rootReducer, applyMiddleware(thunk)),
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 47,
        columnNumber: 7
      }
    }, /*#__PURE__*/React.createElement(ThemeProvider, {
      theme: this.props.theme ? this.props.theme : theme,
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 51,
        columnNumber: 9
      }
    }, /*#__PURE__*/React.createElement("div", {
      className: "container-el",
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 52,
        columnNumber: 11
      }
    }, /*#__PURE__*/React.createElement(App, {
      onSubmit: this.props.onSubmit,
      formData: this.props.data,
      predefinedEndpoint: this.props.predefinedEndpoint,
      fileUploadUrl: this.props.fileUploadUrl,
      conditionableFields: this.props.conditionableFields,
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 53,
        columnNumber: 13
      }
    }))));
  };

  return FormBuilder;
}(React.Component);

export default FormBuilder;
